@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,6 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 
-#include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kpushbutton.h>
@@ -37,7 +36,7 @@
 
 CaptureDialog::CaptureDialog(QWidget *parent)
  : KDialogBase( Plain, i18n("New Capture"), Default|Ok|Cancel, Cancel, parent, "newcapture",
-                /*modal*/true, /*separator*/false, KGuiItem (i18n("&Start"), "ok") )
+                /*modal*/true, /*separator*/false, KGuiItem (i18n("&Start"), "ok"/*KDE 4 icon name: dialog-ok*/) )
 {
   KIconLoader* il = KGlobal::iconLoader();
 
@@ -81,7 +80,7 @@ CaptureDialog::CaptureDialog(QWidget *parent)
 
   KPushButton* m_redetect = new KPushButton( groupBox, "m_rescan" );
   m_redetect->setText( i18n( "Re&detect Interfaces" ) );
-  m_redetect->setIconSet( il->loadIconSet( "reload", KIcon::Small ) );
+  m_redetect->setIconSet( il->loadIconSet( "reload", KIcon::Small ) ); // KDE 4 icon name: view-refresh
   QWhatsThis::add( m_redetect, i18n( "Updates the Interface combobox scanning your system again about its network interfaces." ) );
 
   ifaceSelectLay->addWidget( textLabel );
