@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -125,11 +125,11 @@ QString FrameProtocolManager::strSubProtocol() const
     {
       case ETHERTYPE_IP:
         // IP protocol
-        subproto = ip.strProtocol();
+        subproto = ip.protocolName();
         break;
       case ETHERTYPE_ARP:
         // ARP protocol
-        subproto = arp.strProtocol();
+        subproto = arp.protocolName();
         break;
     }
   }
