@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,6 +19,7 @@
  ***************************************************************************/
 
 #include <unistd.h>
+#include <math.h>
 
 #include <stdio.h>
 #include <signal.h>
@@ -62,7 +63,7 @@
 #include "ksniffer.h"
 #include "capturedialog.h"
 #include "options/ksnifferoptiondialog.h"
-#include "protocols/protocolnamelist.h"
+#include "protocols/portnumbernamelist.h"
 #include "sniffer.h"
 #include "packetmanager.h"
 #include "packet.h"
@@ -72,29 +73,36 @@
 
 #include "errorcode.h"
 
-KSniffer::KSniffer()
+KSniffer::KSniffer(const bool captureEnabled)
   : /*KSnifferIface( "KSniffer-Interface" ),*/ KMainWindow( 0, "KSniffer", 0 )
 {
+  // if the installation has problems with ksniff disable the "New Capture" button
+  m_captureEnabled = captureEnabled;
+
   // accept dnd
   setAcceptDrops(true);
 
-  m_mainWidgetUI = new KSnifferMainWidget( this );
-
-  // tell the KMainWindow that this is indeed the main widget
-  setCentralWidget( m_mainWidgetUI );
-
   // assign global configuration pointer
   m_config = kapp->config();
 
   // then, setup our actions
   setupActions();
 
-  // reading application settings
-  m_options = new CaptureOptions();
-
   // set into m_options the available options directly from the ksnifferrc configuration file
   readSettings();
 
+  m_portNumberNameList = new PortNumberNameList();
+
+  // define the main widget (the view) of KSniffer
+  m_mainWidgetUI = new KSnifferMainWidget( this );
+
+  // tell the KMainWindow that this is indeed the main widget
+  setCentralWidget( m_mainWidgetUI );
+
+  // set the view widget configuration
+  m_mainWidgetUI->setOptions( m_options );
+  m_mainWidgetUI->setPortNumberNameList( m_portNumberNameList );
+
   // prepare the Splash screen to show if needed
   QSplashScreen *splash = 0;
   if (m_options->showSplash())
@@ -112,15 +120,6 @@ KSniffer::KSniffer()
     }
   }
 
-  m_protocolNameList = new ProtocolNameList();
-
-  // set the view widget configuration
-  m_mainWidgetUI->setOptions( m_options );
-  m_mainWidgetUI->setProtocolNameList( m_protocolNameList );
-
-  // option just assigned
-  m_optionChanged = false;
-
   // show a status bar
   statusBar()->show();
 
@@ -143,17 +142,17 @@ KSniffer::KSniffer()
 
   // we need a PacketManager to "store" packets and manage them for the View
   // and we had to specify the temporary directory in the constructor parameters
-  m_packets = new PacketManager( this, "packetmanager" );
+  m_packets = new PacketManager( this, "packetmanager", m_portNumberNameList );
   m_packets->setFilePath( m_options->tmpFilePath() );
 
   m_sniffer = new Sniffer( m_options );
 
   // we define how to manage new captured packets:
     //  1 - store the packet in a PacketList (calling savePacket)
-    connect( m_sniffer, SIGNAL(gotPacket(ptrPacketType, struct pcap_pkthdr, long, int, int)),
+  connect( m_sniffer, SIGNAL(gotPacket(ptrPacketType, struct pcap_pkthdr, long, int, int)),
              m_packets, SLOT(savePacket(ptrPacketType, struct pcap_pkthdr, long, int, int)) );
     //  2 - display the packet into the View
-    connect( m_packets, SIGNAL(savedPacket(long, PacketManager *)), m_mainWidgetUI, SLOT(displayPacket(long, PacketManager *)) );
+  connect( m_packets, SIGNAL(savedPacket(long, PacketManager *)), m_mainWidgetUI, SLOT(displayPacket(long, PacketManager *)) );
 
   // Setting System tray icon if needed
   // prepare all the stuff for the show/hide tray bar...
@@ -186,7 +185,7 @@ KSniffer::KSniffer()
   m_sysTray->contextMenu()->insertSeparator( 3 );
   preferences->plug( m_sysTray->contextMenu(), 4 );
 
-    // ...now show tray bar if needed
+  // ...now show tray bar if needed
   if (m_showTrayBar)
     m_sysTray->show();
 
@@ -204,7 +203,7 @@ KSniffer::KSniffer()
   m_wroteTmpLocalFile = false;
 
   m_timer = new QTimer(this);
-  connect( m_timer, SIGNAL(timeout()), this, SLOT(checkIfSniffing()));
+  connect( m_timer, SIGNAL(timeout()), this, SLOT(checkIfSniffing()) );
 
   // delete the splash if it's been used
   if (splash)
@@ -224,14 +223,14 @@ KSniffer::~KSniffer()
   delete m_mainWidgetUI;
   delete m_actOpenRecent;
   delete m_timer;
-  delete m_protocolNameList;
+  delete m_portNumberNameList;
 }
 
 void KSniffer::load(const KURL& url)
 {
   QString target;
-  // the below code is what you should normally do.  in this
-  // example case, we want the url to our own.  you probably
+  // the below code is what you should normally do. In this
+  // example case, we want the url to our own. You probably
   // want to use this code instead for your app
 
   #if 0
@@ -256,7 +255,7 @@ void KSniffer::load(const KURL& url)
   m_sniffer->setCaptureOptions( m_options );
 
   // maybe a pcap file want to be loaded
-  if ( m_sniffer->checkFile( url.path() ) == Sniffer::RIGHT_FORMAT_FILE )
+  if ( m_sniffer->checkFile( url.path() ) == Sniffer::CORRECT_FORMAT_FILE )
   {
     if (m_packets->packetAvailable())
     {
@@ -329,24 +328,27 @@ void KSniffer::load(const KURL& url)
 void KSniffer::setupActions()
 {
   // the action New Capture
-  m_actNew = KStdAction::openNew( this, SLOT( slotNewCapture()), actionCollection(), "capt_new" );
+  m_actNew = KStdAction::openNew( this, SLOT(slotNewCapture()), actionCollection(), "capt_new" );
   m_actNew->setWhatsThis( i18n( "<b>New Capture</b><br>Start a new packet-capture session." ) );
   m_actNew->setText( i18n( "New Capture..." ) );
 
+  // enable the "New Capture" just if no problem with ksniff permissions
+  m_actNew->setEnabled( m_captureEnabled );
+
   // the action Open Captured-Packet File
-  m_actOpen = KStdAction::open( this, SLOT( slotOpen()), actionCollection(), "capt_open" );
+  m_actOpen = KStdAction::open( this, SLOT(slotOpen()), actionCollection(), "capt_open" );
   m_actOpen->setWhatsThis( i18n("<b>Open</b><br>Open a previous packet-capture session file.") );
 
   // the action Open Recent Captured-Packet File
-  m_actOpenRecent = KStdAction::openRecent(this, SLOT( slotOpen( const KURL& ) ), actionCollection(), "capt_open_recent" );
+  m_actOpenRecent = KStdAction::openRecent(this, SLOT(slotOpen(const KURL&)), actionCollection(), "capt_open_recent" );
 
   // the action Save Captured-Packet File
-  m_actSave = KStdAction::save( this, SLOT( slotSave()), actionCollection(), "capt_save" );
+  m_actSave = KStdAction::save( this, SLOT(slotSave()), actionCollection(), "capt_save" );
   m_actSave->setWhatsThis( i18n( "<b>Save</b><br>Save the current packet-capture session." ) );
   m_actSave->setEnabled( false );
 
   // the action Save Captured-Packet File As
-  m_actSaveAs = KStdAction::saveAs( this, SLOT( slotSaveAs()), actionCollection(), "capt_save_as" );
+  m_actSaveAs = KStdAction::saveAs( this, SLOT(slotSaveAs()), actionCollection(), "capt_save_as" );
   m_actSaveAs->setWhatsThis( i18n( "<b>Save As...</b><br>Save into a file the current packet-capture session." ) );
   m_actSaveAs->setEnabled( false );
 
@@ -416,7 +418,7 @@ void KSniffer::readProperties( KConfig *config )
   m_actOpenRecent->setEnabled( true ); // force enabling
   m_actOpenRecent->setToolTip( i18n("Click to open a file\nClick and hold to open a recent file") );
 
-  m_snifferOption->getOptions( m_options );
+  m_ksnifferConfig->getOptions( m_options );
 
   m_mustShowPacketsNow = !m_options->showAfter();
 }
@@ -424,12 +426,15 @@ void KSniffer::readProperties( KConfig *config )
 
 void KSniffer::readSettings()
 {
+  // reading application settings
+  m_options = new CaptureOptions();
+
   m_actOpenRecent->loadEntries( m_config );
   m_actOpenRecent->setEnabled( true ); // force enabling
   m_actOpenRecent->setToolTip( i18n("Click to open a file\nClick and hold to open a recent file") );
 
   // set into m_options the sniffer options (ShowAfter, TrayBar, TmpDirectory, Warn, PassivePopUp, ShowSplash)
-  m_snifferOption->getOptions( m_options );
+  m_ksnifferConfig->getOptions( m_options );
 
   m_mustShowPacketsNow = !m_options->showAfter();
   m_showTrayBar = m_options->showTrayBar();
@@ -511,21 +516,12 @@ void KSniffer::slotNewCapture()
   // create a new window
   //(new KSniffer)->show();
 
-  //FIXME: always to get the "show after" parameter because if not then the new capture forgot
-  // don't show packet if required. First time ok, but later the m_options->showAfter() is not
-  // correct than bug... Try to fix it better: m_optionChanged not useful anymore
-
-  /*if (m_optionChanged)
-  {
-    // option changed during sniffing
-    m_mainWidgetUI->setOptions( m_options );
-    m_optionChanged = false;
-  }*/
   m_action = ACT_DO_NOTHING;
 
   // set into m_options the available options directly from the ksnifferrc configuration file
-  // just for the Show After option
-  m_snifferOption->getShowAfterOptions( m_options );
+  // just for the Show After option and for the Raw Frame Position
+  m_ksnifferConfig->getShowAfterOptions( m_options );
+  m_ksnifferConfig->getRawFramePosition( m_options );
   m_mainWidgetUI->setOptions( m_options );
 
   // remember if the packets has to be displayed or not when stop sniffing
@@ -538,6 +534,21 @@ void KSniffer::slotNewCapture()
 
   if (cod->exec())
   {
+    // something can be chand, so read again options
+    //  - set into m_options the sniffer options (ShowAfter, TrayBar, TmpDirectory, Warn, PassivePopUp, ShowSplash)
+    m_ksnifferConfig->getOptions( m_options );
+
+    //  - reassign some GUI configurations
+    m_mustShowPacketsNow = !m_options->showAfter();
+    m_showTrayBar = m_options->showTrayBar();
+
+    // show tray bar if needed
+    if (m_showTrayBar)
+      m_sysTray->show();
+    else
+      m_sysTray->hide();
+
+    // now we can "start"...
     if (m_packets->packetAvailable() && m_needToSave)
       if ( KMessageBox::warningContinueCancel( this,
               i18n("<p>Packet-capture session data available. If you want to start a " \
@@ -606,15 +617,11 @@ void KSniffer::slotOpen( const KURL& urlParam )
     if (url0.isEmpty())
     {
       // no file to open
+      readyStatusbar();
       return;
     }
     url = url0;  // real URL on which operate: to have always a local file
-    kdDebug() << "File to open: " << url.prettyURL() << endl;
-    QFile file( url.path() );
-    m_filesize = file.size();
-    kdDebug() << "++++++++++ file: " << m_filesize << " bytes" << endl;
-    m_packets->setFilename( url.path() );
-
+    //kdDebug() << "File to open: " << url.prettyURL() << endl;
     if ( !url.isEmpty() )
     {
       if ( !(isLocal = url.isLocalFile()) )
@@ -655,6 +662,21 @@ void KSniffer::slotOpen( const KURL& urlParam )
         }
         url = tmpFile->name();
       }
+      QFile file( url.path() );
+      m_filesize = file.size();
+      if (!file.exists())
+      {
+        KMessageBox::sorry(this, i18n( "<b>%1</b> not found." ).arg(url0.prettyURL()) );
+        readyStatusbar();
+        return;
+      }
+      else if (m_filesize == 0)
+      {
+        KMessageBox::sorry(this, i18n( "<b>%1</b> is empty. I cannot manage it." ).arg(url0.prettyURL()) );
+        readyStatusbar();
+        return;
+      }
+
       switch ( result = m_sniffer->checkFile( url.path() ) )
       {
         case Sniffer::BAD_FORMAT_FILE:
@@ -667,7 +689,7 @@ void KSniffer::slotOpen( const KURL& urlParam )
             delete tmpFile;
           break;
 
-        case Sniffer::RIGHT_FORMAT_FILE:
+        case Sniffer::CORRECT_FORMAT_FILE:
           // standard filedialog
           m_actOpenRecent->addURL( url );
           if ( m_packets->packetAvailable() )
@@ -723,17 +745,23 @@ void KSniffer::slotOpen( const KURL& urlParam )
     }
     else
       result = Sniffer::NO_FILE_SELECTED;
-  } while ((result != Sniffer::RIGHT_FORMAT_FILE) && (result != Sniffer::NO_FILE_SELECTED));
+  } while ((result != Sniffer::CORRECT_FORMAT_FILE) && (result != Sniffer::NO_FILE_SELECTED) && (result != Sniffer::FILE_NOT_FOUND));
   readyStatusbar();
 
-  if ( (result != Sniffer::NO_FILE_SELECTED) && (result == Sniffer::RIGHT_FORMAT_FILE) )
+  if ( (result != Sniffer::NO_FILE_SELECTED)
+        && (result == Sniffer::CORRECT_FORMAT_FILE))
   {
     // to avoid crash disable sorting
     m_mainWidgetUI->setSortList( false );
 
     // set capture options
     if (isLocal)
+    {
       m_options->setSniffingFilename( url.path() );
+
+      // tell the view what file use to get packets
+      m_packets->setFilename( url.path() );
+    }
     else
     {
       m_options->setSniffingFilename( tmpFile->name() );
@@ -749,8 +777,8 @@ void KSniffer::slotOpen( const KURL& urlParam )
     if (m_wroteTmpLocalFile && !isLocal)
     {
       // need to remove old temporary file
-      unlink( m_options->tmpFilePath() );
-      kdDebug() << "++++++++++++++++++ removed old temporary file: " << m_options->tmpFilePath() << endl;
+      unlink( m_options->tmpFilePath().ascii() );
+      //kdDebug() << "++++++++++++++++++ removed old temporary file: " << m_options->tmpFilePath() << endl;
       m_wroteTmpLocalFile = false;
     }
 
@@ -776,7 +804,7 @@ void KSniffer::slotSave()
   {
     // copy file from temporary file directory
     QString tmp = m_options->tmpFilePath();
-    kdDebug() << "saving file: " << tmp << endl;
+    //kdDebug() << "saving file: " << tmp << endl;
     m_action |= ACT_SAVING_PACKETS;
     KURL src( tmp );
     KURL dest(m_strFilename);
@@ -799,7 +827,7 @@ void KSniffer::slotSaveAs()
   changeStatusbar( i18n("Save captured-packets as...") );
 
   KURL dest = KFileDialog::getSaveURL();
-  kdDebug() << "saving file: " << m_options->tmpFilePath() << endl;
+  //kdDebug() << "saving file: " << m_options->tmpFilePath() << endl;
   KURL src( m_options->tmpFilePath() );
   if (!dest.isEmpty())
   {
@@ -828,9 +856,9 @@ void KSniffer::slotSaveAs()
     if ((m_action & ACT_QUIT_APPL) == ACT_QUIT_APPL)
     {
       //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFilePath() << endl;
-      unlink( m_options->tmpFilePath() );
+      unlink( m_options->tmpFilePath().ascii() );
       //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFileConfigPath() << endl;
-      unlink( m_options->tmpFileConfigPath() );
+      unlink( m_options->tmpFileConfigPath().ascii() );
     }
 }
 
@@ -899,17 +927,16 @@ void KSniffer::slotStop()
   // it doesn't need to store packets anymore
   m_packets->acceptPacket( false );
 
-  if (m_sniffProcess->normalExit())
+  if (!m_loadFromFile)
   {
-    if (m_sniffProcess->exitStatus() == SNIFF_NETWORK_ERROR)
+    if (m_sniffProcess->normalExit())
     {
-      KMessageBox::error( this, i18n("<p>A network error occurred.<br>Cannot continue capturing packets.</p>"));
+      if (m_sniffProcess->exitStatus() == SNIFF_NETWORK_ERROR)
+      {
+        KMessageBox::error( this, i18n("<p>A network error occurred.<br>Cannot continue capturing packets.</p>"));
+      }
     }
-    else
-      kdDebug() << " m_sniffProcess->exitStatus(): " << m_sniffProcess->exitStatus() << endl;
   }
-  else
-    kdDebug() << "m_sniffProcess->normalExit() is FALSE" << endl;
   stopSniffing();
 
   // reset continue sniffing variable
@@ -921,7 +948,7 @@ void KSniffer::slotStop()
     if (m_mustShowPacketsNow || m_startedShowing)
     {
       // if you want you can load a new file or start a new capture session
-      m_actNew->setEnabled(true);
+      m_actNew->setEnabled(m_captureEnabled);
       m_actOpen->setEnabled(true);
       m_actOpenRecent->setEnabled( true );
       // print is not implemented better set it not enabled
@@ -959,7 +986,6 @@ void KSniffer::slotStop()
         m_actSaveAs->setEnabled( true );
 
         // ok you can enable sorting now
-        //FIXME: this sorting will freeze GUI
         m_mainWidgetUI->setSortList(true);
       }
     }
@@ -978,7 +1004,7 @@ void KSniffer::slotStop()
       m_actSaveAs->setEnabled( false );
 
       // if you want you can load a new file or start a new capture session
-      m_actNew->setEnabled(true);
+      m_actNew->setEnabled(m_captureEnabled);
       m_actOpen->setEnabled(true);
       m_actOpenRecent->setEnabled( true );
       // print is not implemented better set it not enabled
@@ -1014,13 +1040,16 @@ void KSniffer::slotStop()
 
 void KSniffer::stopSniffing()
 {
-  if (m_sniffProcess)
+  if (m_sniffProcess && !m_loadFromFile)
   {
     m_sniffProcess->kill();
     delete m_sniffProcess;
     m_sniffProcess = NULL;
   }
-  m_sniffer->stopSniffing();
+  if (m_loadFromFile)
+    m_sniffer->stopSniffing();
+  else
+    m_sniffer->waitingToStop();
 
   // the thread has a little delay to stop, so before
   // to start a new thread the last has to be finished
@@ -1031,18 +1060,22 @@ void KSniffer::stopSniffing()
     while (m_sniffer->running())
       usleep(1000);
   }
-  // tell the GUI that the siffing process has stopped
+  // tell the GUI that the sniffing process has stopped
   m_mainWidgetUI->stopSniffing();
 }
 
 
+void KSniffer::waitingToStop(bool value)
+{
+  m_sniffer->waitingToStop(value);
+}
+
+
 void KSniffer::showAfterDisplay( const KURL& url )
 {
   m_startedShowing = true;
-  //kdDebug() << "File to open: " << url.prettyURL() << endl;
   QFile file( url.path() );
   m_filesize = file.size();
-  //kdDebug() << "++++++++++ file: " << m_filesize << " bytes" << endl;
   m_packets->setFilename( url.path() );
 
   // Packets available, need to save them, continue losting data
@@ -1081,14 +1114,13 @@ void KSniffer::showAfterDisplay( const KURL& url )
 
 void KSniffer::checkIfSniffing()
 {
-  kdDebug() << "void KSniffer::checkIfSniffing()" << endl;
   if (!m_sniffer->isSniffing())
   {
     // if you want you can load a new file or start a new capture session
-    m_actNew->setEnabled(true);
+    m_actNew->setEnabled(m_captureEnabled);
     m_actOpen->setEnabled(true);
     m_actOpenRecent->setEnabled( true );
-    // print is not implemented better set it not enabled
+    // print is not implemented better set it as not enabled
     //m_actPrint->setEnabled(true);
 
     // and you don't need to stop or continue any capture anymore
@@ -1141,11 +1173,12 @@ void KSniffer::checkIfSniffing()
   }
   else
   {
+    double x = trunc((double)m_sniffer->packetsTotalSize() / m_filesize * 10000) / 100;
     if (m_loadFromFile)
       if (!m_startedShowing)
-        changeStatusbar( i18n("Getting packets from file: %1%").arg( (double)m_sniffer->packetsTotalSize() / m_filesize * 100) );
+        changeStatusbar( i18n("Getting packets from file: %1%").arg( x ) );
       else
-        changeStatusbar( i18n("Displaying captured packets: %1%").arg( (double)m_sniffer->packetsTotalSize() / m_filesize * 100) );
+        changeStatusbar( i18n("Displaying captured packets: %1%").arg( x ) );
   }
 }
 
@@ -1206,9 +1239,9 @@ void KSniffer::slotQuit()
   {
     // ...remove the pcap temporary file
     //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFilePath() << endl;
-    unlink( m_options->tmpFilePath() );
+    unlink( m_options->tmpFilePath().ascii() );
     //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFileConfigPath() << endl;
-    unlink( m_options->tmpFileConfigPath() );
+    unlink( m_options->tmpFileConfigPath().ascii() );
   }
 
   // delay exit from KSniffer if Job's not finished
@@ -1219,7 +1252,6 @@ void KSniffer::slotQuit()
 // decide what to do when the Job is finished
 void KSniffer::copyingJobFinished( KIO::Job *job )
 {
-  kdDebug() << "void KSniffer::copyingJobFinished( KIO::Job *job )" << endl;
   if (job->error() == 0)
   {
     // no error happened
@@ -1233,15 +1265,18 @@ void KSniffer::copyingJobFinished( KIO::Job *job )
 
     // no need to save it again: just done
     m_actSave->setEnabled(false);
-    m_actSaveAs->setEnabled(false);
+
+    // but you could want to save the file elsewhere
+    m_actSaveAs->setEnabled(true);
+
     m_strFilename = QString::null;
     if ((m_action & ACT_QUIT_APPL) == ACT_QUIT_APPL)
     {
       // deleting temporary files
       //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFilePath() << endl;
-      unlink( m_options->tmpFilePath() );
+      unlink( m_options->tmpFilePath().ascii() );
       //kdDebug() << "+++++++++ I'm going to delete " << m_options->tmpFileConfigPath() << endl;
-      unlink( m_options->tmpFileConfigPath() );
+      unlink( m_options->tmpFileConfigPath().ascii() );
     }
   }
   else
@@ -1292,12 +1327,14 @@ void KSniffer::optionsSettings()
 {
   // popup some sort of preference dialog, here
   KSnifferOptionDialog *dialogSettings = new KSnifferOptionDialog(this, "SettingsDialog", true);
-  connect( dialogSettings, SIGNAL( trayBarShown( bool ) ), this, SLOT( showTrayBar( bool ) ) );
+  connect( dialogSettings, SIGNAL( trayBarShown(bool) ), this, SLOT( showTrayBar(bool) ) );
+  connect( dialogSettings, SIGNAL( changedRawFormPosition(bool) ), m_mainWidgetUI, SLOT( changeRawFormPosition(bool) ) );
   if (dialogSettings->exec())
   {
     // redo your settings
     resetOptions();
     m_sniffer->setCaptureOptions( m_options );
+    m_mainWidgetUI->setOptions( m_options );
   }
 
   delete dialogSettings;
@@ -1324,9 +1361,9 @@ void KSniffer::readyStatusbar()
 }
 
 
-void KSniffer::showTrayBar( bool show)
+void KSniffer::showTrayBar( bool showTrayBar )
 {
-  if ( show )
+  if ( showTrayBar )
   {
     // show the tray bar
     m_sysTray->show();
@@ -1336,7 +1373,10 @@ void KSniffer::showTrayBar( bool show)
     // hide the tray bar
     m_sysTray->hide();
   }
-  m_showTrayBar = show;
+  m_showTrayBar = showTrayBar;
+
+  if (!isShown() && !showTrayBar)
+    show();
 }
 
 
@@ -1496,14 +1536,14 @@ void KSniffer::startLiveSniffing( const QString& interface )
 
   if (m_mustShowPacketsNow)
   {
-    kdDebug() << "ok, packets will be displayed" << endl;
+    //kdDebug() << "ok, packets will be displayed" << endl;
     m_packets->acceptPacket( true );
     m_mainWidgetUI->displayPacket( true );
   }
   else
   {
     // if you have to display packet after capture is useful don't accept packets to display
-    kdDebug() << "ok, NO packets will be displayed" << endl;
+    //kdDebug() << "ok, NO packets will be displayed" << endl;
     m_mainWidgetUI->displayPacket( false );
   }
 
@@ -1513,6 +1553,10 @@ void KSniffer::startLiveSniffing( const QString& interface )
   *m_sniffProcess << m_options->tmpFileConfigPath();
   connect(m_sniffProcess, SIGNAL(processExited(KProcess *)), this, SLOT(slotStop()));
   m_sniffProcess->start();
+
+  // we are going to sniff, so we can't wait stopping now
+  m_sniffer->waitingToStop(false);
+
   m_sniffer->startSniffing();
 }
 
@@ -1542,16 +1586,13 @@ void KSniffer::startSniffingFromFile()
 
 void KSniffer::resetOptions()
 {
-  m_snifferOption->getOptions( m_options );
+  m_ksnifferConfig->getOptions( m_options );
 
   if ( !m_sniffer->isSniffing() )
   {
     //FIXME: the setting for the view is deprecated
     m_mainWidgetUI->setOptions( m_options );
   }
-  else
-    // during capture the options don't take effect
-    m_optionChanged = true;
 }
 
 #include "ksniffer.moc"
