@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -49,10 +49,11 @@
 #include "ksniffermainwidget.h"
 #include "ksnifferviewitem.h"
 #include "packetmanager.h"
-#include "frames/frameheader.h"
+#include "frames/frameheadermanager.h"
 #include "frames/frameprotocolmanager.h"
 #include "protocols/protocolmanager.h"
 #include "options/captureoptions.h"
+#include "options/ksnifferconfig.h"
 
 #include "kinfoip.h"
 
@@ -63,6 +64,7 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
 {
   if ( !name )
     setName( "MainWidget" );
+
   m_mainViewLayout = new QVBoxLayout( this, 11, 6, "MainWidgetLayout");
   m_mainViewLayout->setAlignment( Qt::AlignTop );
 
@@ -99,16 +101,26 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
   m_detail->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)3, 0, 0,
     m_detail->sizePolicy().hasHeightForWidth() ) );
 
-  m_rawPacketArea = new QTextEdit( horizSplitter, "rawbyte" );
-  QToolTip::add( m_rawPacketArea, i18n( "Show raw packet content" ) );
-  QWhatsThis::add( m_rawPacketArea, i18n( "In this area you will see the bytes contained by a network "
+  m_rawPacketAreaRight = new QTextEdit( horizSplitter, "rawbyte" );
+  QToolTip::add( m_rawPacketAreaRight, i18n( "Show raw packet content" ) );
+  QWhatsThis::add( m_rawPacketAreaRight, i18n( "In this area you will see the bytes contained by a network "
       "packet when you click on it from the packet list." ) );
 
-  m_rawPacketArea->hide();  // show this widget when you click onto a packet from the list
-  QFont mono( "Monospace" );
-  m_rawPacketArea->setFont( mono );
+  m_rawPacketAreaRight->hide();  // show this widget when you click onto a packet from the list
+  QFont mono( "Monospace", 8 );
+  m_rawPacketAreaRight->setFont( mono );
   QFontMetrics fm( mono );
-  m_rawPacketArea->setFixedWidth( fm.width("Z")*22 );
+  m_rawPacketAreaRight->setMinimumWidth( fm.width("Z")*77 );
+
+  // the raw packet under the frame
+  m_rawPacketAreaUnder = new QTextEdit( vertSplitter, "rawbytevert" );
+  QToolTip::add( m_rawPacketAreaUnder, i18n( "Show raw packet content" ) );
+  QWhatsThis::add( m_rawPacketAreaUnder, i18n( "In this area you will see the bytes contained by a network "
+      "packet when you click on it from the packets list." ) );
+
+  m_rawPacketAreaUnder->hide();  // show this widget when you click onto a packet from the list
+  QFont monofont( "Monospace", 10 );
+  m_rawPacketAreaUnder->setFont( monofont );
 
   // search line
   QToolButton* toolbtn = new QToolButton( this );
@@ -142,9 +154,7 @@ KSnifferMainWidget::KSnifferMainWidget( QWidget* parent, const char* name )
   // we don't need sorting detail
   m_detail->setSortColumn(-1);
 
-  QWhatsThis::add( m_list, i18n("<p>In this area you get all the captured packets.</p><p>You cannot "\
-    "sort view lines while you are capturing packets. Just after you stopped packet-capture you can "\
-    "sort view lines again clicking on the column header you want sort by.</p>"\
+  QWhatsThis::add( m_list, i18n("<p>In this area you get all the captured packets.</p>"\
     "<p>If you click with the right mouse button on a source or destination IP address you can get a "\
     "popup menu and choose the program that can give you some IP information (<i>whois</i>, "\
     "<i>traceroute</i>, ...).</p>") );
@@ -205,6 +215,7 @@ KSnifferMainWidget::~KSnifferMainWidget()
 {
   // no need to delete child widgets, Qt does it all for us
   delete m_info;
+  delete m_options;
 }
 
 
@@ -297,6 +308,7 @@ void KSnifferMainWidget::setSortList(bool value)
   if (value)
   {
     /*
+    // this will "freeze" the GUI
     setUpdatesEnabled(false);
     m_list->setSortColumn(0);
     setUpdatesEnabled(true);
@@ -311,14 +323,22 @@ void KSnifferMainWidget::setSortList(bool value)
 
 void KSnifferMainWidget::setOptions( CaptureOptions *options )
 {
-  // just this option is needed
+  // just these three options are needed
   m_options->setShowAfter( options->showAfter() );
+  m_options->setRawFramePosition( options->rawFramePosition() );
+  m_options->setShowProtocolName( options->showProtocolName() );
+
+  // assign the m_rawPacketArea
+  if (m_options->rawFramePosition() == "under")
+    m_rawPacketArea = m_rawPacketAreaUnder;
+  else
+    m_rawPacketArea = m_rawPacketAreaRight;
 }
 
 
-void KSnifferMainWidget::setProtocolNameList( ProtocolNameList *pnl )
+void KSnifferMainWidget::setPortNumberNameList( PortNumberNameList *pnnl )
 {
-  m_protocolNameList = pnl;
+  m_portNumberNameList = pnnl;
 }
 
 
@@ -342,7 +362,6 @@ bool KSnifferMainWidget::displayingPacket()
 
 void KSnifferMainWidget::updateFilter()
 {
-  kdDebug() << "updating the filter view: " << m_needToUpdateSearch << endl;
   if (m_needToUpdateSearch)
     // update the view by the filter if really needed
     m_listSearch->updateSearch();
@@ -351,7 +370,6 @@ void KSnifferMainWidget::updateFilter()
 
 void KSnifferMainWidget::startSniffing()
 {
-  kdDebug() << "void KSnifferMainWidget::startSniffing()+++++++++++++++++" << endl;
   if (!m_options->showAfter())
     // just if the show packet is in real time you need to enable the view for the update
     if (m_needToUpdateSearch)
@@ -363,7 +381,6 @@ void KSnifferMainWidget::stopSniffing()
 {
   // to stop sniffing the GUI has to update the view and stop the timer
   updateFilter();
-  kdDebug() << "stopping the timer..." << endl;
   m_timer->stop();
 }
 
@@ -371,17 +388,24 @@ void KSnifferMainWidget::stopSniffing()
 void KSnifferMainWidget::updateView()
 {
   // when you load a file you have to appy this updateView at the end of the load
-  kdDebug() << "void KSnifferMainWidget::updateView()" << endl;
   if (m_needToUpdateSearch)
   {
     m_mutex.lock();
     m_listSearch->updateSearch();
     m_mutex.unlock();
-    kdDebug() << "mutex" << endl;
   }
 }
 
 
+void KSnifferMainWidget::changeRawFormPosition( bool rightPosition )
+{
+  if (rightPosition)
+    m_rawPacketArea = m_rawPacketAreaRight;
+  else
+    m_rawPacketArea = m_rawPacketAreaUnder;
+}
+
+
 void KSnifferMainWidget::displayPacket(long ord, PacketManager *pktMan)
 {
   // if the packets have to be displayed when captured or the
@@ -396,13 +420,11 @@ void KSnifferMainWidget::displayPacket(long ord, PacketManager *pktMan)
 
     if (m_firstInsert)
     {
-      m_lastElem = new KSnifferViewItem( m_list, pktMan );
+      m_lastElem = new KSnifferViewItem( m_list, pktMan, m_portNumberNameList, m_options->showProtocolName() );
       m_firstInsert = false;
     }
     else
-    {
-      m_lastElem = new KSnifferViewItem( m_list, m_lastElem, pktMan );
-    }
+      m_lastElem = new KSnifferViewItem( m_list, m_lastElem, pktMan, m_portNumberNameList, m_options->showProtocolName() );
   }
 
   // we need to save PacketManager class reference first time
@@ -475,7 +497,7 @@ void KSnifferMainWidget::showDetails( QListViewItem * item )
       QListViewItem *itemFrame2 = new QListViewItem( m_detail, itemFrame1, i18n("Protocol information: %1").arg( fpm.getProtocol()) );
       QListViewItem *subitemFrame2 = new QListViewItem ( itemFrame2, *list.begin() );
 
-      for( QStringList::Iterator it = ++list.begin(); it != list.end(); ++it)
+      for( QStringList::Iterator it = ++list.begin(); it != list.end(); ++it )
       {
         if (*it == "*open")
         {
@@ -488,7 +510,7 @@ void KSnifferMainWidget::showDetails( QListViewItem * item )
           subitemFrame2 = new QListViewItem( itemFrame2, subitemFrame2, *it );
       }
 
-      ProtocolManager pm(m_packetManager->getPacket(), fpm.getSubProtocol(), m_protocolNameList);
+      ProtocolManager pm(m_packetManager->getPacket(), fpm.getSubProtocol(), m_portNumberNameList);
       list = pm.headerLines();
       if (!list.isEmpty())
       {
@@ -512,26 +534,7 @@ void KSnifferMainWidget::showDetails( QListViewItem * item )
       }
     }
   }
-
-  // show raw packet area
-  m_rawPacketArea->show();
-  ptrPacketType pkt = m_packetManager->getPacket();
-  QString packetOut;
-  int length = m_packetManager->packetSize();
-  int i = 0;
-  while (i < length)
-  {
-    if ((pkt[i] >= ' ') && (pkt[i] <= '~'))
-      packetOut += pkt[i];
-    else
-      packetOut += '.';
-    i++;
-    if (i % 16 == 0)
-      packetOut += "\n";
-    else if (i % 8 == 0)
-      packetOut += "  ";
-  }
-  m_rawPacketArea->setText( packetOut );
+  showRawPacketDetails();
 
   // expand item lines if needed
   if (m_bExpanding0)
@@ -564,6 +567,77 @@ void KSnifferMainWidget::viewSubtree(QStringList::Iterator &it, QListViewItem **
 }
 
 
+void KSnifferMainWidget::showRawPacketDetails()
+{
+  QString stuff, packetOut, packetRaw;
+
+  // show the correct raw packet area: can happen that it's been selected
+  // a different area area during the view
+  if (m_rawPacketArea == m_rawPacketAreaRight)
+  {
+    m_rawPacketAreaUnder->hide();
+    m_rawPacketAreaUnder->clear();
+  }
+  else
+  {
+    m_rawPacketAreaRight->hide();
+    m_rawPacketAreaRight->clear();
+  }
+
+  m_rawPacketArea->show();
+
+  ptrPacketType pkt = m_packetManager->getPacket();
+  int length = m_packetManager->packetSize();
+  int i = 0;
+  while (i < length)
+  {
+    if (i % 16 == 0)
+    {
+      QString hexAddress = QString("%1").arg(i, 0, 16);
+      stuff.fill('0', 4 - hexAddress.length());
+
+      // 'stuff' contains the starting address in hexadecimal
+      packetOut += stuff + hexAddress + "  ";
+    }
+    if ((pkt[i] >= ' ') && (pkt[i] <= '~'))
+      packetRaw += pkt[i];
+    else
+      packetRaw += '.';
+    QString hex = QString("%1").arg(pkt[i], 0, 16);
+
+    // preappend '0' if the hex number is just a digit
+    if (hex.length() == 1)
+      packetOut += "0" + hex + " ";
+    else
+      packetOut += hex + " ";
+
+    i++;
+
+    // got the 16 bytes per line?
+    if (i % 16 == 0)
+    {
+      packetOut += "  " + packetRaw + "\n";
+      packetRaw = "";
+    }
+    else if (i % 8 == 0)
+    {
+      packetRaw += "  ";
+      packetOut += " ";
+    }
+  }
+
+  // align the last packetRaw line
+  if (i % 16 < 8)
+    stuff.fill(' ', 51 - (i % 16) * 3);
+  else
+    stuff.fill(' ', 50 - (i % 16) * 3);
+  packetOut += stuff + packetRaw;
+
+  // display the RAW packet in the view
+  m_rawPacketArea->setText( packetOut );
+}
+
+
 void KSnifferMainWidget::clickedMouseButton(QListViewItem* item, const QPoint& pos, int column)
 {
   QString ip;
