@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,35 +19,40 @@
  ***************************************************************************/
 
 #include <qlistview.h>
-#include <qstring.h>
-
-#include <kdebug.h>
 
 #include "packetmanager.h"
+#include "protocols/portnumbernamelist.h"
 #include "ksnifferviewitem.h"
 
-KSnifferViewItem::KSnifferViewItem( QListView *parent, PacketManager *pm )
-  : QListViewItem( parent ), m_packetData( pm )
+KSnifferViewItem::KSnifferViewItem( QListView *parent, PacketManager *pm, PortNumberNameList *pnnl, bool showProtocolName )
+  : QListViewItem( parent ), m_packetData( pm ), m_portNumberNameList( pnnl ), m_showProtocolName(showProtocolName)
 {
   init();
 }
 
-KSnifferViewItem::KSnifferViewItem( QListView *parent, QListViewItem *after, PacketManager *pm )
-  : QListViewItem( parent, after ), m_packetData( pm )
+
+KSnifferViewItem::KSnifferViewItem( QListView *parent, QListViewItem *after, PacketManager *pm, PortNumberNameList *pnnl,
+  bool showProtocolName) : QListViewItem( parent, after ), m_packetData( pm ), m_portNumberNameList( pnnl ),
+    m_showProtocolName(showProtocolName)
 {
   init();
 }
 
+
 void KSnifferViewItem::init()
 {
   setText( 0, QString::number( m_packetData->getFrameNumber() ) );
   setText( 1, m_packetData->strTimeStamp() );
   setText( 2, m_packetData->strSourceAddress() );
   setText( 3, m_packetData->strDestinationAddress() );
-  setText( 4, m_packetData->strProtocol() );
+  if (m_showProtocolName)
+    setText( 4, m_packetData->strProtocolServiceName() );
+  else
+    setText( 4, m_packetData->strProtocol() );
   setText( 5, m_packetData->strInfo() );
 }
 
+
 int KSnifferViewItem::compare( QListViewItem *i, int col, bool ascending ) const
 {
   if (col == 0) // frame number
