@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,12 +24,13 @@
 class QListView;
 class QListViewItem;
 class PacketManager;
+class PortNumberNameList;
 
 class KSnifferViewItem : public QListViewItem
 {
   public:
-    KSnifferViewItem( QListView *parent, PacketManager *pm );
-    KSnifferViewItem( QListView *parent, QListViewItem *after, PacketManager *pm );
+    KSnifferViewItem( QListView *parent, PacketManager *pm, PortNumberNameList *pnnl, bool showProtocolName );
+    KSnifferViewItem( QListView *parent, QListViewItem *after, PacketManager *pm, PortNumberNameList *pnnl, bool showProtocolName );
 
     virtual int compare( QListViewItem * i, int col, bool ascending ) const;
 
@@ -37,6 +38,8 @@ class KSnifferViewItem : public QListViewItem
     void init();
 
     PacketManager *m_packetData;
+    PortNumberNameList *m_portNumberNameList;
+    bool m_showProtocolName;
 };
 
 #endif
