@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -135,6 +135,18 @@ void CaptureOptions::setSniffingType( const QString& sniffType )
 }
 
 
+void CaptureOptions::setRawFramePosition( const QString& position )
+{
+  m_rawFramePosition = position;
+}
+
+
+void CaptureOptions::setShowProtocolName( const bool& display )
+{
+  m_showProtocolName = display;
+}
+
+
 QString CaptureOptions::sniffingInterface() const
 {
   return m_strSniffingInterface;
@@ -241,7 +253,7 @@ int CaptureOptions::sniffType() const
 }
 
 
-QString CaptureOptions::sniffingType()
+QString CaptureOptions::sniffingType() const
 {
   QString res;
 
@@ -263,3 +275,15 @@ QString CaptureOptions::sniffingType()
 
   return res;
 }
+
+
+QString CaptureOptions::rawFramePosition() const
+{
+  return m_rawFramePosition;
+}
+
+
+bool CaptureOptions::showProtocolName() const
+{
+  return m_showProtocolName;
+}
