@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,8 +50,10 @@ class CaptureOptions
     void setPacketsInfoSizeUnits( const int& sizeunit );
     void setPacketsInfoTimeUnits( const int& timeunit );
     void setSniffingType( const QString& sniffType );
+    void setRawFramePosition( const QString& position );
+    void setShowProtocolName( const bool& display );
 
-    // get propeties members
+    // get properties members
     QString sniffingInterface() const;
     QString sniffingFilename() const;
     QString tmpFilePath() const;
@@ -68,7 +70,9 @@ class CaptureOptions
     int packetsInfoSizeUnits() const;
     int packetsInfoTimeUnits() const;
     int sniffType() const;
-    QString sniffingType();
+    QString sniffingType() const;
+    QString rawFramePosition() const;
+    bool showProtocolName() const;
 
   private:
     QString m_strSniffingInterface; // sniffing interface
@@ -86,6 +90,10 @@ class CaptureOptions
     int m_packetsInfoSizeUnits;
     int m_packetsInfoTimeUnits;
     int m_sniffType;
+
+    QString m_rawFramePosition;
+
+    bool m_showProtocolName;
 };
 
 #endif
