@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,8 +32,6 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 
-#include <kdebug.h>
-
 #include "snifferoptiontab.h"
 #include "captureoptions.h"
 
@@ -46,8 +44,6 @@ SnifferOptionTab::SnifferOptionTab(QWidget *parent, const char *name)
   m_stopButtons << m_checkTime;
   m_editTempDir->setMode( KFile::Directory );
 
-  connect( m_checkWarning, SIGNAL(clicked()), this, SLOT(checkWarning()) );
-
   connect( m_checkPackets, SIGNAL(clicked()), this, SLOT(checkSelectPackets()) );
   connect( m_checkSize, SIGNAL(clicked()), this, SLOT(checkSelectSize()) );
   connect( m_checkTime, SIGNAL(clicked()), this, SLOT(checkSelectTime()) );
@@ -63,23 +59,6 @@ SnifferOptionTab::SnifferOptionTab(QWidget *parent, const char *name)
          "file for packet-captured session.</p><p>If you want the temporary folder "\
          "can be changed here before starting a new capture session.</p>") );
 
-  QToolTip::add( m_afterDisplay, i18n("The packets will be displayed just when you stop capturing them") );
-  QWhatsThis::add( m_afterDisplay,
-    i18n("<p>The default option is <i>showing packets when you capture it</i>. "\
-         "If you check this, when KSniffer will capture packets it will not display them. "\
-         "Just when you stop capturing all captured packets will be displayed.</p>"
-         "<p>You can change this option during sniffing, but the effect will "\
-         "take effect after you make a <b>New capture</b>. If you want simply "\
-         "to stop packet-capture for a while you can use the <i>Pause Capture</i> "\
-         "feature from the <i>Capture</i> menu.</p>") );
-
-  QToolTip::add( m_trayBar, i18n("KSniffer can be added to the KDE tray bar clicking here") );
-  QWhatsThis::add( m_trayBar,
-    i18n("<p>The default option is <i>not showing KSniffer icon in the tray bar</i>."\
-         "If you want to add KSniffer to the tray bar you have to click here. "\
-         "In this way you can access some useful KSniffer functions like start a new "\
-         "capure, stop it, pause/continue it directly from the tray bar.</p>") );
-
   QWhatsThis::add( m_checkPackets,
     i18n("<p>If you check this, you can capture just a certain packets number. "\
          "After that number, capture will stop automatically.</p>"\
@@ -108,26 +87,6 @@ SnifferOptionTab::SnifferOptionTab(QWidget *parent, const char *name)
          "<i>packets time</i>.</p>") );
 
   QToolTip::add( m_packetsTime, i18n("Packets time after you want to stop capturing") );
-
-  QWhatsThis::add( m_checkWarning,
-     i18n("<p>If you check this, you will be warn when the capture stops and you got no packets. "\
-          "You can choose if you want to be warned with a modal window or with a pop up one "\
-          "checking or not the following sub option.</p>") );
-
-  QToolTip::add( m_checkWarning, i18n("Warning when the capture stops and you got no packets") );
-
-  QWhatsThis::add( m_checkPassiveWarn,
-     i18n("<p>If you check this, you will be warn when the capture stops and you got no packets "\
-          "with a passive pop up, otherwise you will warn by a modal window that stops the "\
-          "application till when you click on the OK button.</p>") );
-
-  QToolTip::add( m_checkPassiveWarn, i18n("Warning with a passive pop up when the capture stops and you got no packets") );
-
-  QWhatsThis::add( m_checkShowSplash,
-     i18n("<p>If you check this, you will see a splash screen for some seconds at the KSniffer startup.</p>") );
-
-  QToolTip::add( m_checkShowSplash, i18n("It will show a splash screen at the startup") );
-
 }
 
 
@@ -136,12 +95,6 @@ SnifferOptionTab::~SnifferOptionTab()
 }
 
 
-void SnifferOptionTab::checkWarning()
-{
-  m_checkPassiveWarn->setEnabled(m_checkWarning->isChecked());
-}
-
-
 void SnifferOptionTab::checkStopManually()
 {
   exclusiveSelectOf( 0 );
@@ -184,16 +137,6 @@ void SnifferOptionTab::exclusiveSelectOf( int which )
     m_stopButtonSelected = "by size";
   else if (which == 3)
     m_stopButtonSelected = "by time";
-  //kdDebug() << "which: " << which << " selected: '" << m_stopButtonSelected << "'" << endl;
-}
-
-
-void SnifferOptionTab::getShowAfterOptions( CaptureOptions *options )
-{
-  // get just the Show After configuration
-  KConfig* c = kapp->config();
-  c->setGroup( "General Options" );
-  options->setShowAfter( c->readBoolEntry( "Show packets after stopped capture" , false ) );
 }
 
 
@@ -231,21 +174,9 @@ void SnifferOptionTab::readSettings()
 {
   KConfig* c = kapp->config();
   c->setGroup( "General Options" );
-  m_afterDisplay->setChecked( c->readBoolEntry( "Show packets after stopped capture" , false ) );
-  m_trayBar->setChecked( c->readBoolEntry( "Show Tray Bar", false ) );
-
   QString tempdir = c->readPathEntry( "Temp dir", KGlobal::dirs()->resourceDirs( "tmp" ).first() );
   m_editTempDir->setURL( tempdir );
 
-  m_checkWarning->setChecked( c->readBoolEntry( "Warn with no packets", true ) );
-  if (!m_checkWarning->isChecked())
-    m_checkPassiveWarn->setEnabled( false );
-  else
-    m_checkPassiveWarn->setChecked( c->readBoolEntry( "Passive pop up warning with no packets", false ) );
-
-  // check if the Splashscreen has to be displayed
-  m_checkShowSplash->setChecked( c->readBoolEntry("Show splash", true) );
-
   // load stopping capture type: manually, ...
   c->setGroup( "Capture Type Options" );
   m_stopButtonSelected = c->readEntry( "Stopping Type", "manually" );
@@ -279,7 +210,6 @@ bool SnifferOptionTab::saveSettings()
 {
   KConfig* c = kapp->config();
   c->setGroup( "General Options" );
-  c->writeEntry( "Show splash", m_checkShowSplash->isChecked() );
 
   // saving temporary directory URL
   QString tempDir = m_editTempDir->url();
@@ -320,16 +250,9 @@ bool SnifferOptionTab::saveSettings()
   }
 
   m_editTempDir->setURL( fi.absFilePath() );
-  c->writeEntry( "Version", "0.2" );
-  c->writeEntry( "Show packets after stopped capture", m_afterDisplay->isChecked() );
-  c->writeEntry( "Show Tray Bar", m_trayBar->isChecked() );
+  c->writeEntry( "Version", "0.3.2" );
   c->writePathEntry( "Temp dir", m_editTempDir->url() );
 
-  c->writeEntry( "Warn with no packets", m_checkWarning->isChecked() );
-  c->writeEntry( "Passive pop up warning with no packets", m_checkPassiveWarn->isChecked() );
-
-  emit trayBarShown( m_trayBar->isChecked() );
-
   // save stopping capture type: manually, ...
   c->setGroup( "Capture Type Options" );
   c->writeEntry( "Stopping Type", m_stopButtonSelected );
