@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,7 +42,8 @@ public:
   QString senderIpAddress() const;
   QString targetMacAddress() const;
   QString targetIpAddress() const;
-  QString strProtocol() const;
+  QString protocolName() const;
+  QString strInfo() const;
 
   QStringList headerLines() const;
 
