@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,10 +29,15 @@ class QStringList;
 class IcmpProtocol
 {
   public:
+    IcmpProtocol();
     IcmpProtocol(Packet *packet);
 
+    void setPacket(Packet *packet);
+
     u_int8_t type() const;
     QString strType() const;
+    QString strCode() const;
+    QString strInfo() const;
     u_int8_t code() const;
     u_int16_t checksum() const;
     u_int16_t id() const;
@@ -41,6 +46,7 @@ class IcmpProtocol
 
   private:
     Packet *m_packet;
+    struct IcmpHdr *m_icmp;
 };
 
 #endif
