@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,48 +25,36 @@
 #include <qstringlist.h>
 
 #include <klocale.h>
-//#include <kdebug.h>
+#include <kdebug.h>
 
+#include "portnumbernamelist.h"
 #include "ip-protocol.h"
+#include "icmp-protocol.h"
+#include "tcp-protocol.h"
+#include "udp-protocol.h"
 #include "../packet.h"
 #include "../packetstructures.h"
 
 IpProtocol::IpProtocol(Packet *packet)
 {
-/*
-  m_packet = packet;
-  m_length = packet->frameHeaderLength();
-  */
   init(packet);
 }
 
 
 IpProtocol::IpProtocol(Packet *packet, int length)
 {
-/*
-  m_packet = packet;
-  m_length = length;
-*/
   init(packet, length);
 }
 
 
 IpProtocol::IpProtocol(ptrPacketType packet)
 {
-/*
-  m_packet = (Packet *)packet;
-  m_length = m_packet->frameHeaderLength();
-*/
   init((Packet *)packet);
 }
 
 
 IpProtocol::IpProtocol(ptrPacketType packet, int length)
 {
-/*
-  m_packet = (Packet *)packet;
-  m_length = length;
-*/
   init((Packet *)packet, length);
 }
 
@@ -75,46 +63,38 @@ void IpProtocol::init(Packet *packet, int length)
 {
   m_packet = packet;
   m_length = length != -1 ? length : packet->frameHeaderLength();
+  m_ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
+  m_PortNumberNameList = NULL;
 }
 
 
 u_int8_t IpProtocol::version() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ( (u_int8_t) ip->version );
+  return ( (u_int8_t) m_ip->version );
 }
 
 
 int IpProtocol::headerLength() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return (ip->ihl << 2);
+  return (m_ip->ihl << 2);
 }
 
 
 u_int16_t IpProtocol::totalLength() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ntohs(ip->tot_len);
+  return ntohs(m_ip->tot_len);
 }
 
 
 u_int16_t IpProtocol::id() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ntohs(ip->id);
+  return ntohs(m_ip->id);
 }
 
 
 QString IpProtocol::flagR() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  u_int16_t frag_off = ntohs(ip->frag_off);
+  u_int16_t frag_off = ntohs(m_ip->frag_off);
   QString ret;
 
   if ( frag_off & (1 << 13) )
@@ -128,9 +108,7 @@ QString IpProtocol::flagR() const
 
 QString IpProtocol::flagDF() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  u_int16_t frag_off = ntohs(ip->frag_off);
+  u_int16_t frag_off = ntohs(m_ip->frag_off);
   QString ret;
 
   if ( frag_off & (1 << 14) )
@@ -144,9 +122,7 @@ QString IpProtocol::flagDF() const
 
 QString IpProtocol::flagMF() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  u_int16_t frag_off = ntohs(ip->frag_off);
+  u_int16_t frag_off = ntohs(m_ip->frag_off);
   QString ret;
 
   if ( frag_off & (1 << 15) )
@@ -160,61 +136,118 @@ QString IpProtocol::flagMF() const
 
 u_int16_t IpProtocol::fragmentOffset() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ( ntohs(ip->frag_off) & 8191 );  // 8191 is 00011111 11111111 in binary
+  return ( ntohs(m_ip->frag_off) & 8191 );  // 8191 is 00011111 11111111 in binary
 }
 
 
 u_int8_t IpProtocol::ttl() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ( (u_int8_t) ip->ttl );
+  return ( (u_int8_t) m_ip->ttl );
 }
 
 
 u_int8_t IpProtocol::protocol() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ( (u_int8_t) ip->protocol );
+  return ( (u_int8_t) m_ip->protocol );
 }
 
 
-QString IpProtocol::strProtocol() const
+QString IpProtocol::protocolName() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
   QString proto;
 
-  switch ( (u_int8_t) ip->protocol )
+  switch ( (u_int8_t) m_ip->protocol )
   {
+    // this case has to be removed. We have to parse: /etc/protocols
     case 1:
       proto = "ICMP";
       break;
+    case 2:
+      proto = "IGMP";
+      break;
     case 6:
       proto = "TCP";
       break;
     case 17:
       proto = "UDP";
       break;
+    case 88:
+      proto = "EIGRP";
+      break;
   }
 
   return proto;
 }
 
+
+QString IpProtocol::applicationProtocolName() const
+{
+  QString result;
+  TcpProtocol *tcp;
+  UdpProtocol *udp;
+
+  switch ( (u_int8_t) m_ip->protocol )
+  {
+    // this case has to be removed. We have to parse: /etc/protocols
+    case 1:
+      result = "ICMP";
+      break;
+    case 2:
+      result = "IGMP";
+      break;
+    case 6:
+      tcp = new TcpProtocol;
+      tcp->setPacket((Packet*)((ptrPacketType)m_packet + m_length + headerLength()));
+      if (m_PortNumberNameList == NULL)
+        result = "TCP";
+      else
+      {
+        // IANA: The Dynamic and/or Private Ports are those from 49152 through 65535
+        if (tcp->sourcePort() < 30000)
+          result = m_PortNumberNameList->detectPortNumberName( tcp->sourcePort() ).upper();
+        else
+          result = m_PortNumberNameList->detectPortNumberName( tcp->destinationPort() ).upper();
+        if (result.isEmpty())
+          result = "TCP";
+      }
+      break;
+    case 17:
+      udp = new UdpProtocol;
+      udp->setPacket((Packet*)((ptrPacketType)m_packet + m_length + headerLength()));
+      if (m_PortNumberNameList == NULL)
+        result = "UDP";
+      else
+      {
+        // IANA: The Dynamic and/or Private Ports are those from 49152 through 65535
+        if (udp->sourcePort() < 30000)
+          result = m_PortNumberNameList->detectPortNumberName( udp->sourcePort() ).upper();
+        else
+          result = m_PortNumberNameList->detectPortNumberName( udp->destinationPort() ).upper();
+        if (result.isEmpty())
+          result = "UDP";
+      }
+      break;
+    case 88:
+      result = "EIGRP";
+      break;
+    default:
+      result = "-";
+      break;
+  }
+
+  return result;
+}
+
+
 u_int16_t IpProtocol::checksum() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-
-  return ntohs(ip->check);
+  return ntohs(m_ip->check);
 }
 
 
 QString IpProtocol::sourceAddress() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-  unsigned char *x = (unsigned char *) (&ip->saddr);
+  unsigned char *x = (unsigned char *) (&m_ip->saddr);
 
   return QString("%1.%2.%3.%4").arg(x[0]).arg(x[1]).arg(x[2]).arg(x[3]);
 }
@@ -222,8 +255,7 @@ QString IpProtocol::sourceAddress() const
 
 QString IpProtocol::destinationAddress() const
 {
-  struct IpHdr *ip = (struct IpHdr*) ( (ptrPacketType)m_packet + m_length );
-  unsigned char *x = (unsigned char *) (&ip->daddr);
+  unsigned char *x = (unsigned char *) (&m_ip->daddr);
 
   return QString("%1.%2.%3.%4").arg(x[0]).arg(x[1]).arg(x[2]).arg(x[3]);
 }
@@ -231,7 +263,44 @@ QString IpProtocol::destinationAddress() const
 
 QString IpProtocol::strInfo() const
 {
-  return "IP packet information";
+  QString result;
+  IcmpProtocol icmp;
+  TcpProtocol tcp;
+  UdpProtocol udp;
+
+  switch ( protocol() )
+  {
+    // this case has to be removed. We have to parse: /etc/protocols
+    case 1:
+      icmp.setPacket((Packet*)((ptrPacketType)m_packet + m_length + headerLength()));
+      result = icmp.strInfo();
+      break;
+    case 2:
+      result = "IGMP";
+      break;
+    case 6:
+      tcp.setPacket((Packet*)((ptrPacketType)m_packet + m_length + headerLength()));
+      result = tcp.strInfo();
+      break;
+    case 17:
+      udp.setPacket((Packet*)((ptrPacketType)m_packet + m_length + headerLength()));
+      result = udp.strInfo();
+      break;
+    case 88:
+      result = "EIGRP";
+      break;
+    default:
+      result = "-";
+      break;
+  }
+
+  return result;
+}
+
+
+void IpProtocol::setPortNumberNameList( PortNumberNameList *pnnl )
+{
+  m_PortNumberNameList = pnnl;
 }
 
 
@@ -251,7 +320,7 @@ QStringList IpProtocol::headerLines() const
   list << "*close";
   list << i18n("IP protocol field", "Fragment offset: %1").arg( fragmentOffset() );
   list << i18n("IP protocol field", "Time to live: %1").arg( ttl() );
-  list << i18n("IP protocol field", "Protocol: %1 (0x%2)").arg( strProtocol() ).arg( protocol(), 0, 16 );
+  list << i18n("IP protocol field", "Protocol: %1 (0x%2)").arg( protocolName() ).arg( protocol(), 0, 16 );
   list << i18n("IP protocol field", "Header checksum: 0x%1").arg( checksum(), 0, 16 );
   list << i18n("IP protocol field", "Source address: %1").arg( sourceAddress() );
   list << i18n("IP protocol field", "Destination address: %1").arg( destinationAddress() );
