@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2007 by Giovanni Venturi                           *
+ *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
  *   giovanni@ksniffer.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,6 +21,7 @@
 #ifndef IPPROTOCOL_H
 #define IPPROTOCOL_H
 
+class PortNumberNameList;
 class Packet;
 class QString;
 class QStringList;
@@ -45,12 +46,15 @@ public:
   u_int16_t fragmentOffset() const;
   u_int8_t ttl() const;
   u_int8_t protocol() const;
-  QString strProtocol() const;
+  QString protocolName() const;
+  QString applicationProtocolName() const;
   u_int16_t checksum() const;
   QString sourceAddress() const;
   QString destinationAddress() const;
   QString strInfo() const;
 
+  void setPortNumberNameList( PortNumberNameList *pnnl );
+
   QStringList headerLines() const;
 
 protected:
@@ -58,7 +62,9 @@ protected:
 
 private:
   Packet *m_packet;
+  struct IpHdr *m_ip;
   int m_length;
+  PortNumberNameList *m_PortNumberNameList;
 };
 
 #endif
