@@ -1,7 +1,7 @@
 // define the KSniffer version
 
 #ifndef APPVER
-#define APPVER "0.3"
+#define APPVER "0.3.2"
 #endif
 
 #ifndef TEMP_PCAP_FILE_NAME
